@@ -123,6 +123,15 @@ def get_timezone(tz_name: str, fallback_tz_name: Optional[str] = None) -> Tuple[
 
     return tz, final_tz_name
 
+def convert_str_to_datetime(time: str, fmt: str, time_zone: Optional[str] = None):
+    time = datetime.strptime(time, fmt)
+    if time_zone is not None:
+        time = time.replace(tzinfo=get_timezone(str(time_zone))[0])
+    return time
+
+def convert_time_with_timezone(time: datetime, target_tz: str):
+    target_tz = get_timezone(str(target_tz))[0]
+    return time.replace(tzinfo=target_tz)
 
 def convert_time_by_timezone(original_time: datetime,
                            original_tz: Union[str, tzinfo],
